# geotask


[![image](https://img.shields.io/pypi/v/geotask.svg)](https://pypi.python.org/pypi/geotask)
[![image](https://img.shields.io/conda/vn/conda-forge/geotask.svg)](https://anaconda.org/conda-forge/geotask)


**A demo python package**


-   Free software: MIT License
-   Documentation: https://nazifa02.github.io/geotask
    

## Features

-   TODO


## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter)
